@@ -64,13 +64,11 @@ X Window System is a trademark of The Open Group.
 #endif
 #include "Xlibint.h"
 
-int
-XAddHost (
-    register Display *dpy,
-    XHostAddress *host)
+static inline int
+changehost (Display *dpy, XHostAddress *host, BYTE mode)
 {
-    register xChangeHostsReq *req;
-    register int length;
+    xChangeHostsReq *req;
+    int length;
     XServerInterpretedAddress *siAddr;
     int addrlen;
 
@@ -83,7 +81,11 @@ XAddHost (
 
     LockDisplay(dpy);
     GetReqExtra (ChangeHosts, length, req);
-    req->mode = HostInsert;
+    if (!req) {
+	UnlockDisplay(dpy);
+	return 0;
+    }
+    req->mode = mode;
     req->hostFamily = host->family;
     req->hostLength = addrlen;
     if (siAddr) {
@@ -99,39 +101,20 @@ XAddHost (
     return 1;
 }
 
+int
+XAddHost (
+    register Display *dpy,
+    XHostAddress *host)
+{
+    return changehost(dpy, host, HostInsert);
+}
+
 int
 XRemoveHost (
     register Display *dpy,
     XHostAddress *host)
 {
-    register xChangeHostsReq *req;
-    register int length;
-    XServerInterpretedAddress *siAddr;
-    int addrlen;
-
-    siAddr = host->family == FamilyServerInterpreted ?
-	(XServerInterpretedAddress *)host->address : NULL;
-    addrlen = siAddr ?
-	siAddr->typelength + siAddr->valuelength + 1 : host->length;
-
-    length = (addrlen + 3) & ~0x3;	/* round up */
-
-    LockDisplay(dpy);
-    GetReqExtra (ChangeHosts, length, req);
-    req->mode = HostDelete;
-    req->hostFamily = host->family;
-    req->hostLength = addrlen;
-    if (siAddr) {
-	char *dest = (char *) NEXTPTR(req,xChangeHostsReq);
-	memcpy(dest, siAddr->type, siAddr->typelength);
-	dest[siAddr->typelength] = '\0';
-	memcpy(dest + siAddr->typelength + 1,siAddr->value,siAddr->valuelength);
-    } else {
-	memcpy((char *) NEXTPTR(req,xChangeHostsReq), host->address, addrlen);
-    }
-    UnlockDisplay(dpy);
-    SyncHandle();
-    return 1;
+    return changehost(dpy, host, HostDelete);
 }
 
 int
